.. _drizcr:

******************************
Cosmic-ray Identification Step
******************************

The cosmic rays and bad pixels are now identified by comparing the input images
with the associated blotted,median-cleaned images created.

.. automodule:: drizzlepac.drizCR
   :members:
   :undoc-members:
